@@ -6,5 +6,7 @@ import sys
 
 from .core import CoreTest
 from .perf import PerfTest
+from .pool import PoolTest
+from .scheduler import SchedulerTest
 
 logging.basicConfig(level=logging.INFO, stream=sys.stderr)
